import leakPasswd

from distutils.core import setup

setup(
    name="leakPasswd",
    version=leakPasswd.__version__,
    description="This is the password leak query module",
    author="lauix",
    author_email="lauixData@gmail.com",
    url="https://github.com/lauixData/leakPasswd",
)
